@@ -148,7 +148,7 @@ def load_csa(trange=['2001-02-01', '2001-02-03'],
 
     local_path = CONFIG['local_data_dir']
     Path(local_path).mkdir(parents=True, exist_ok=True)
-    out_gz = local_path + 'temp_cluster_file.tar.gz'  # Temp file name
+    out_gz = os.path.join(local_path, 'temp_cluster_file.tar.gz')  # Temp file name
 
     # Download the file.
     logging.info("Downloading Cluster data, please wait....")
@@ -178,7 +178,7 @@ def load_csa(trange=['2001-02-01', '2001-02-03'],
     # Get unique set of files.
     f_set = set(f)
     # File list with full path.
-    out_files = [local_path+s for s in list(f_set)]
+    out_files = [os.path.join(local_path, s) for s in list(f_set)]
     out_files = sorted(out_files)
 
     if downloadonly:
