@@ -2,12 +2,14 @@ from pytplot import get_data, store_data
 from .mms_feeps_energy_table import mms_feeps_energy_table
 from pyspedas import tnames
 
+
 def mms_feeps_correct_energies(probes, data_rate, level='l2', suffix=''):
     """
     This function modifies the energy table in FEEPS spectra (intensity, count_rate, counts) variables
        using the function: mms_feeps_energy_table (which is s/c, sensor head and sensor ID dependent)
     
-    Parameters:
+    Parameters
+    -------------
         probes: list of str
             list of probes #, e.g., '4' for MMS4
 
@@ -20,7 +22,8 @@ def mms_feeps_correct_energies(probes, data_rate, level='l2', suffix=''):
         suffix: str
             suffix of the loaded data
 
-    Notes:
+    Notes
+    -------
         BAD EYES are replaced by NaNs
     """
     types = ['top', 'bottom']
@@ -54,4 +57,4 @@ def mms_feeps_correct_energies(probes, data_rate, level='l2', suffix=''):
                     try:
                         store_data(var_name, data={'x': times, 'y': data, 'v': energy_map})
                     except:
-                        continue
\ No newline at end of file
+                        continue
