@@ -1,8 +1,8 @@
 import numpy as np
-
 from pytplot import get_data, store_data
 from pyspedas import tnames
 
+
 def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate = 'brst', suffix = ''):
     """
        Apply flat field correction factors to FEEPS ion/electron data;
@@ -12,7 +12,8 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
            
        from Drew Turner, 1/19/2017
     
-    Parameters:
+    Parameters
+    ---------------
         probes: list of str
             list of probes #, e.g., '4' for MMS4
 
@@ -22,7 +23,8 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
         suffix: str
             suffix of the loaded data
 
-    Notes:
+    Notes
+    ---------------
         From Drew Turner, 1/18/17:
            Here are the correction factors that we need to apply to the current 
            ION counts/rates/fluxes in the CDF files.  
@@ -118,7 +120,7 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
                             i_var = tnames('mms'+probe+'_epd_feeps_'+data_rate+'_'+level+'_'+species_id+'_'+sensor_type+'_intensity_sensorid_'+sensor_id+suffix)
                             c_var = tnames('mms'+probe+'_epd_feeps_'+data_rate+'_'+level+'_'+species_id+'_'+sensor_type+'_counts_sensorid_'+sensor_id+suffix)
 
-                            if cr_var == []:
+                            if not cr_var:
                                 count_rate = None
                             else:
                                 count_rate = get_data(cr_var[0])
@@ -128,7 +130,7 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
                                     continue
                                 store_data(cr_var[0], data={'x': cr_times, 'y': cr_data*correction, 'v': cr_energies})
 
-                            if i_var == []:
+                            if not i_var:
                                 intensity = None
                             else:
                                 intensity = get_data(i_var[0])
@@ -138,7 +140,7 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
                                     continue
                                 store_data(i_var[0], data={'x': i_times, 'y': i_data*correction, 'v': i_energies})
 
-                            if c_var == []:
+                            if not c_var:
                                 counts = None
                             else:
                                 counts = get_data(c_var[0])
@@ -147,6 +149,3 @@ def mms_feeps_flat_field_corrections(probes = ['1', '2', '3', '4'], data_rate =
                                 if np.isnan(c_energies).all():
                                     continue
                                 store_data(c_var[0], data={'x': c_times, 'y': c_data*correction, 'v': c_energies})
-
-
-
