@@ -1,6 +1,7 @@
 from pyspedas import tnames
 from pytplot import get_data, store_data, options
 
+
 def mms_load_fpi_calc_pad(probe='1', level='sitl', datatype='', data_rate='', suffix='', autoscale=True):
     """
     Calculates the omni-directional pitch angle distribution (summed and averaged)
@@ -31,7 +32,8 @@ def mms_load_fpi_calc_pad(probe='1', level='sitl', datatype='', data_rate='', su
         autoscale: bool
             If set, use the default zrange; otherwise, use the min and max of the data for the zrange
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -111,4 +113,4 @@ def mms_load_fpi_calc_pad(probe='1', level='sitl', datatype='', data_rate='', su
         options(pad_avg_name, 'spec', True)
         out_vars.append(pad_avg_name)
 
-        return out_vars
\ No newline at end of file
+        return out_vars
