@@ -6,7 +6,6 @@ from .mms_file_filter import mms_file_filter
 from .mms_get_local_files import mms_get_local_files
 from pytplot import cdf_to_tplot
 from pyspedas.analysis.time_clip import time_clip as tclip
-
 from .mms_config import CONFIG
 
 CONFIG['remote_data_dir'] = 'https://spdf.gsfc.nasa.gov/pub/data/mms/'
@@ -19,8 +18,7 @@ def mms_load_data_spdf(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate
     """
     This function loads MMS data from NASA SPDF into pyTplot variables
 
-    This function is not meant to be called directly. Please see the individual load routines for documentation and use. 
-
+    This function is not meant to be called directly. Please see the individual load routines for documentation and use.
     """
 
     tvars_created = []
@@ -85,11 +83,11 @@ def mms_load_data_spdf(trange=['2015-10-16', '2015-10-17'], probe='1', data_rate
                         for file in files:
                             out_files.append(file)
 
-                    if out_files == []:
+                    if not out_files:
                         logging.info('Searching for local files...')
                         out_files = mms_get_local_files(prb, instrument, drate, lvl, dtype, trange)
 
-                        if out_files == [] and CONFIG['mirror_data_dir'] != None:
+                        if not out_files and CONFIG['mirror_data_dir'] != None:
                             # check for network mirror; note: network mirrors are assumed to be read-only
                             # and we always copy the files from the mirror to the local data directory
                             # before trying to load into tplot variables
