@@ -1,5 +1,3 @@
-
-
 import numpy as np
 
 # use nansum from bottleneck if it's installed, otherwise use the numpy one
@@ -40,7 +38,7 @@ def mms_pgs_make_e_spec(data_in):
     else:
         ave = outbins/data['bins']
 
-    return (outtable, ave)
+    return outtable, ave
 
 
 def find_nearest_neighbor(table, item):
