@@ -1,5 +1,6 @@
-
 from .load import load
+from pyspedas.utilities.datasets import find_datasets
+
 
 def mfe(trange=['2003-10-28', '2003-10-29'],
         datatype='k0',
@@ -720,3 +721,7 @@ def orbit(trange=['2003-10-28', '2003-10-29'],
 
     """
     return load(instrument='spha', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+
+
+def datasets(instrument=None, label=True):
+    return find_datasets(mission='Polar', instrument=instrument, label=label)
